WowArrayIter

Struct WowArrayIter 

pub struct WowArrayIter<'a, T, R>
where T: WowHeaderR + WowHeaderW, R: Read + Seek,
{ /* private fields */ }

Implementations

Source

impl<'a, T, R> WowArrayIter<'a, T, R>
where T: WowHeaderR + WowHeaderW, R: Read + Seek,

pub fn new(reader: &'a mut R, array: WowArray<T>) -> Result<Self>

pub fn next<F>(&mut self, f: F) -> Result<bool>
where F: FnMut(&mut R, Option<T>) -> Result<()>,

Returns Ok(true) if there are items remaining or Ok(false) if not. This iterator needs at least one item to get the item_size, so it will read the first item and call f with Some(item) the first time and None from then on. It’s the user’s responsibility to read the subsequent items. The reader will always be at the correct offset for reading an item at the closure execution start When an Err is returned, it’s no longer safe to call this function again